Type Definition noises_and_patterns::prelude::IsometryMatrix3
source · Expand description
A 3-dimensional direct isometry using a rotation matrix for its rotational part.
Because this is an alias, not all its methods are listed here. See the Isometry type too.
Also known as a rigid-body motion, or as an element of SE(3).